import os
import unittest

from stamdata3.stamdata3 import Stamdata3


class ResourceTestCase(unittest.TestCase):
    def test_resource_id(self):
        stamdata = Stamdata3(os.path.join(os.path.dirname(__file__), 'test_data', 'stamdata.xml'))
        resource = stamdata.resource(53453)
        self.assertEqual(resource.resource_id, 53453)


if __name__ == '__main__':
    unittest.main()



import os
import unittest

from stamdata3.Employment import Employment
from stamdata3.exceptions import InvalidRelation
from stamdata3.stamdata3 import Stamdata3


class TestEmployment(unittest.TestCase):
    def setUp(self) -> None:
        self.stamdata = Stamdata3(os.path.join(os.path.dirname(__file__), 'test_data', 'stamdata.xml'))
        resource = self.stamdata.resource(53453)
        employments = list(resource.employments)
        self.employment: Employment = employments[0]

    def test_resource_id(self):
        self.assertEqual(self.employment.resource_id, '53453')

    def test_relation(self):
        stamdata = Stamdata3(os.path.join(os.path.dirname(__file__), 'test_data', 'stamdata_multi.xml'))
        resource = stamdata.resource(53453)
        employments = list(resource.employments)
        employment: Employment = employments[0]
        self.assertEqual(employment.relation('COST_CENTER').value, '1170')

    def test_invalid_relation(self):
        stamdata = Stamdata3(os.path.join(os.path.dirname(__file__), 'test_data', 'stamdata_multi.xml'))
        resource = stamdata.resource(53453)
        employments = list(resource.employments)
        employment: Employment = employments[0]
        with self.assertRaises(InvalidRelation):
            employment.relation('COST_CENTER_BAD').value


if __name__ == '__main__':
    unittest.main()



from stamdata3.Relation import Relation
from stamdata3.XMLDataHelper import XMLDataHelper
from stamdata3.exceptions import InvalidRelation


class Employment(XMLDataHelper):
    @property
    def resource_id(self):
        return self.data.get('ResourceId')

    @property
    def type(self):
        return self.string('EmploymentType')

    @property
    def type_description(self):
        return self.string('EmploymentTypeDescription')

    @property
    def percentage(self):
        return self.float('Percentage')

    @property
    def post_id(self):
        return self.string('PostId')

    @property
    def post_id_description(self):
        return self.string('PostIdDescription')

    @property
    def post_code(self):
        return self.string('PostCode')

    @property
    def post_code_description(self):
        return self.string('PostCodeDescription')

    @property
    def date_from(self):
        return self.date('DateFrom')

    @property
    def date_to(self):
        return self.date('DateTo')

    @property
    def last_update(self):
        return self.date_time('LastUpdate')

    @property
    def sequence_ref(self):
        return self.int('SequenceRef')

    @property
    def main_position(self):
        return self.bool('MainPosition')

    def relation(self, relation_type):
        relation = self.data.find(
            'Relations/Relation[@ElementType="%s"]' % relation_type)
        if relation is None:
            raise InvalidRelation(
                'Employment %s has no relation of type %s' % (self.data.get('ResourceId'), relation_type))
        else:
            return Relation(relation)

    def __str__(self):
        return '%s %s' % (self.resource_id, self.post_code_description)




from stamdata3.XMLDataHelper import XMLDataHelper


class Organisation(XMLDataHelper):
    @property
    def company_code(self):
        return self.string('CompanyCode')

    @property
    def name(self):
        return self.string('Name')

    @property
    def id(self):
        return self.string('Id')

    @property
    def parent_id(self):
        return self.string('ParentId')

    @property
    def manager(self):
        return self.int('Managers/string')

    @property
    def status(self):
        return self.string('Status')



from datetime import datetime

from stamdata3.Employment import Employment


def map_employment(employment):
    return Employment(employment)


class Resource:
    def __init__(self, employee):
        self.employee = employee

    @property
    def resource_id(self):
        return int(self.employee.find('ResourceId').text)

    @property
    def address(self):
        return self.employee.find('Addresses/Address')

    @property
    def employments(self):
        employments = self.employee.findall('Employments/Employment')
        return map(map_employment, employments)

    def main_position(self):
        employment = self.employee.find(
            'Employments/Employment/MainPosition[.="true"]/..')
        if not employment:
            raise AttributeError('Employee %s has no MainPosition' %
                                 self.resource_id)
        else:
            return Employment(employment)

    @property
    def first_name(self):
        return self.employee.find('FirstName').text

    @property
    def last_name(self):
        return self.employee.find('Surname').text

    @property
    def company_code(self):
        return self.employee.find('CompanyCode').text

    @property
    def birth_date(self):
        date = self.employee.find('Birthdate').text
        return datetime.strptime(date, '%Y-%m-%d')

    @property
    def ssn(self):
        return self.employee.find('SocialSecurityNumber').text

    @property
    def status(self):
        return self.employee.find('Status').text



from xml.etree import ElementTree

from stamdata3.Organisation import Organisation
from stamdata3.Resource import Resource


class Stamdata3:
    root = None

    def __init__(self, file):
        tree = ElementTree.parse(file)
        self.root = tree.getroot()

    def resource(self, resource_id):
        resource = self.root.find(
            './/Resources/Resource/ResourceId[.="%d"]/..' % resource_id)
        if not resource:
            raise ResourceNotFound
        return Resource(resource)

    def resources(self):
        """
        Get all resources

        :rtype: Iterable[Resource]
        """
        resources = self.root.findall('Resources/Resource')
        return map(map_resource, resources)

    def organisations(self):
        """
        Get all organisations

        :rtype: Iterable[Organisation]
        """
        organisations = self.root.findall('Organisations/Organisation')
        return map(map_organisation, organisations)


def map_resource(resource):
    return Resource(resource)


def map_organisation(organisation):
    return Organisation(organisation)


class ResourceNotFound(Exception):
    pass

# stamdata = Stamdata3()
# print(stamdata.employee_address(53898))



import os
import unittest
from typing import List

from stamdata3.Organisation import Organisation
from stamdata3.stamdata3 import Stamdata3
from stamdata3.Resource import Resource


class StamdataTestCase(unittest.TestCase):
    def setUp(self) -> None:
        file = os.path.join(os.path.dirname(__file__), 'test_data', 'stamdata.xml')
        self.stamdata = Stamdata3(file)

    def testResources(self):
        resources = self.stamdata.resources()
        resources = list(resources)

        resource = resources[0]
        self.assertIsInstance(resources[0], Resource)
        self.assertEqual(53453, resource.resource_id)
        self.assertEqual('AK', resource.company_code)

    def testOrganisations(self):
        organisations = self.stamdata.organisations()
        organisations = list(organisations)

        organisation = organisations[0]
        self.assertIsInstance(organisation, Organisation)
        self.assertEqual('AK', organisation.company_code)


if __name__ == "__main__":
    unittest.main()



import os

from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='stamdata3',
    version='v0.1',
    packages=find_packages(),
    include_package_data=True,
    license='GPL',
    description='A Python class structure to work with data from stamdata3 XML files',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/StorFollo-IKT/stamdata3-py',
    author='Anders Birkenes',
    author_email='datagutten@datagutten.net',
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ]
)



class StamdataException(Exception):
    pass


class InvalidRelation(StamdataException):
    pass


class ResourceNotFound(StamdataException):
    pass


class InvalidField(StamdataException):
    pass



from datetime import datetime

from stamdata3.exceptions import InvalidField


class XMLDataHelper:
    def __init__(self, data):
        if data is None:
            raise ValueError('Data is None')
        self.data = data

    def get_field(self, field):
        data = self.data.find(field)
        if data is None:
            raise InvalidField('Field %s does not exist' % field)
        elif data.text is None:
            return None
        else:
            return data.text

    def string(self, field):
        data = self.get_field(field)
        if data is None:
            return None
        else:
            return data

    def bool(self, field):
        data = self.string(field)
        if data == 'false':
            return False
        elif data == 'true':
            return True
        else:
            raise ValueError('Invalid boolean value: %s' % data)

    def int(self, field):
        return int(self.get_field(field))

    def float(self, field):
        return float(self.get_field(field))

    def date(self, field):
        data = self.string(field)
        return datetime.strptime(data, '%Y-%m-%d')

    def date_time(self, field):
        data = self.string(field)
        return datetime.strptime(data, '%Y-%m-%dT%H:%M:%S')



from stamdata3.XMLDataHelper import XMLDataHelper


class Relation(XMLDataHelper):
    @property
    def value(self):
        return self.string('Value')

    @property
    def description(self):
        return self.string('Description')

    @property
    def date_from(self):
        return self.date('DateFrom')

    @property
    def date_to(self):
        return self.date('DateFrom')

    def __str__(self):
        return '%s %s' % (self.value, self.description)
